Text with a name like Åsmund Ødegård works in general.

This block (in format html) triggers use of `mako`. For all formats, `mako` has problem with non-ASCII characters anywhere in the text. The remedy for all formats is to read the file with UTF-8 encoding. With --debug one can see the internal str/unicode representation of the text through the various stages of the text transformation process.

\( b = 1 \) is a value suggested by Åsmund Ødegård.